@@ -1,11 +1,12 @@
+from EmuPBk.MCMC.core import Core
+from EmuPBk.MCMC.like import LikeModule, ComplexLikeModule
 import os
 import time
-from EmuPBk.MCMC.core import Core
-from EmuPBk.MCMC.like import LikeModule
 from cosmoHammer.util import Params
 from cosmoHammer import MpiCosmoHammerSampler
 from cosmoHammer import CosmoHammerSampler
 from cosmoHammer import LikelihoodComputationChain
+
 #  from cosmoHammer.pso.MpiParticleSwarmOptimizer import MpiParticleSwarmOptimizer
 
 # The parameter space is defined
@@ -19,37 +20,41 @@ params = Params(("NoH", [275, 10, 550, 3]),
 
 
 class RunMCMC:
-
     """ sampler & MPI sampler class """
-    def __init__(self, data, nbins, noise=0., div=1.0, name='pk'):
+
+    def __init__(self, data, nbins, model, noise=0., div=1.0, like_func='n'):
         """
         :param data: load your data
         :param nbins: number of k-modes in powerspectrum OR
          number of triangle contributions in bispectrum (for covariance matrix)
         :param noise: system noise, e.g. SKA, MWA noise response (if any), default 0.0,
         :param div: likelihood normalization factor, default 1.0,
-        :param name: use ('pk','bk') for powerspectrum, bispectrum
+        :param like_func: choose between complex likelihood function (use 'c'), and normal function (use 'n')
+
         """
         chain = LikelihoodComputationChain(min=params[:, 1], max=params[:, 2])
         chain.params = params
-        chain.addLikelihoodModule(LikeModule(data, nbins, noise, div))
+        if like_func == 'n':
+            chain.addLikelihoodModule(LikeModule(data, nbins, noise, div, model))
+        else:
+            chain.addLikelihoodModule(ComplexLikeModule(data, ntri, noise, div, region))
         self.chain = chain
-        self.name = name
 
-    def load_existing_model(self):
+    def load_existing_model(self, name='pk'):
         """
         Use the existing ANN models for MCMC analysis
+        :param name: use ('pk','bk') for powerspectrum, bispectrum
         """
-
+        self.name = name
         if self.name == 'pk':
-            self.chain.addCoreModule(Core(load_model=path+'pk.h5', norm=1.))
+            self.chain.addCoreModule(Core(load_model=path + 'pk.h5', norm=1.))
 
         elif self.name == 'bk':
-            self.chain.addCoreModule(Core(load_model=path+'bk.h5', norm=100.))
+            self.chain.addCoreModule(Core(load_model=path + 'bk.h5', norm=100.))
 
         self.chain.setup()
 
-    def load_model(self, load_model, name='pk', norm=1.):
+    def load_model(self, load_model, norm=1., name='bk'):
 
         """
         :param load_model: load your own model, (give the path)
@@ -75,7 +80,7 @@ class RunMCMC:
         #   params[:, 0] = pso.gbest.position
         mpi_sampler = MpiCosmoHammerSampler(params=params,
                                             likelihoodComputationChain=self.chain,
-                                            filePrefix='%s' % self.name+'%d' % num,
+                                            filePrefix='%s' % self.name + '%d' % num,
                                             walkersRatio=walker_ratio,
                                             burninIterations=burnin,
                                             sampleIterations=samples, threadCount=threads)
@@ -103,17 +108,17 @@ class RunMCMC:
         """
 
         sampler = CosmoHammerSampler(
-                params=params,
-                likelihoodComputationChain=self.chain,
-                filePrefix='%s' % self.name + '%d' % num,
-                walkersRatio=walker_ratio,
-                burninIterations=burnin,
-                sampleIterations=samples, threadCount=threads)
+            params=params,
+            likelihoodComputationChain=self.chain,
+            filePrefix='%s' % self.name + '%d' % num,
+            walkersRatio=walker_ratio,
+            burninIterations=burnin,
+            sampleIterations=samples, threadCount=threads)
 
         print("started sampling:")
         start = time.time()
         sampler.startSampling()
         end = time.time()
-        tics = end-start
+        tics = end - start
         print("The time taken %.2f sec. done!" % tics)
-        print('Done!')
+        print('Done!')
\ No newline at end of file
