@@ -1,7 +1,21 @@
 import numpy as np
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 from tensorflow import keras as ks
 
+plt.style.use('classic')
+mpl.rcParams['text.usetex'] = True
+mpl.rcParams['xtick.major.size'] = 8
+mpl.rcParams['xtick.minor.size'] = 4
+mpl.rcParams['xtick.major.width'] = 1.5
+mpl.rcParams['xtick.minor.width'] = 1.2
+mpl.rcParams['ytick.major.size'] = 8
+mpl.rcParams['ytick.minor.size'] = 4
+mpl.rcParams['ytick.major.width'] = 1.5
+mpl.rcParams['ytick.minor.width'] = 1.2
+mpl.rcParams['patch.linewidth']=1.8
+mpl.rcParams['axes.linewidth']=1.8
+
 model = ks.models.Sequential()
 Dense = ks.layers.Dense
 
@@ -10,7 +24,7 @@ class ANN:
 
     def __init__(self, data, parameters, name='powerspectrum',
                  epochs=100, batch=10, optimizer='adam',
-                 kernel_init='uniform', validation=0.038):
+                 kernel_init='uniform', validation=0.08):
         """
                 : data: must be an array (N*k_bins)
                 : params: must be an array (N*n_parameters)
@@ -134,30 +148,47 @@ class ANN:
         return: gives the plot of model accuracy and model loss for the training set and the test set
         """
 
-        plt.figure(figsize=(16, 6))
-
-        plt.suptitle(r'Accuracy and Loss on the validation set for %s' % self.name)
+        plt.figure(figsize=(13, 4), facecolor='w', edgecolor='w')
+        plt.suptitle(r'$\rm Accuracy~\&~Loss$', size=23)
         plt.subplot(1, 2, 1)
-        c = list(np.arange(0, 1, 0.2))
-        c.append(0.96)
-        plt.yticks(c)
-        plt.plot(history.history['acc'], lw=3, color='purple')
-        plt.plot(history.history['val_acc'], lw=1, color='yellow', alpha=0.7)
-        plt.hlines(y=0.96, xmin=0, xmax=self.epochs, linestyles='dashdot', lw=2)
-
-        plt.title('model accuracy')
-        plt.ylabel('accuracy')
-        plt.xlabel('epoch')
-        plt.legend(['training', 'validation'], loc='lower right')
+        plt.grid(True, lw=1)
+        plt.ylim(0,1.2)
+        plt.xlim(-10, len(history.item().get('val_loss'))+10)
+        plt.plot(history.item().get('acc'), color='purple', lw=2)
+        plt.plot(history.item().get('val_acc'), color='orange',lw=2)
+        plt.xticks(size=16)
+        plt.yticks(size=16)
+        plt.ylabel(r'$\rm Accuracy$', size=18, )
+        plt.xlabel(r'$\rm Epochs$', size=18, )
 
         plt.subplot(1, 2, 2)
-
-        plt.plot(history.history['loss'], color='purple')
-        plt.plot(history.history['val_loss'], color='orange')
-        plt.hlines(y=0, xmin=0, xmax=self.epochs, linestyles='dashed', lw=1)
-        plt.title('model loss')
-        plt.ylabel('loss')
-        plt.xlabel('epoch')
-        plt.legend(['training', 'validation'], loc='upper right')
+        plt.grid(True, lw=1)
+        plt.plot(history.item().get('loss'), color='purple', lw=2)
+        plt.plot(history.item().get('val_loss'), color='orange', lw=2)
+        plt.ylabel(r'$\rm Loss$', size=18, color='k', )
+        plt.xticks(size=16, color='k', )
+        plt.yticks(size=16, color='k')
+        plt.ylim(-10, np.max(history.item().get('val_loss'))+10)
+        plt.xlim(-10,len(history.item().get('val_loss'))+10)
+        plt.xlabel(r'$\rm Epochs$', size=18, color='k')
+        plt.legend([r'$\rm Training$', r'$\rm Validation$'], loc='best', prop={'size': 20}, labelcolor='k')
         plt.savefig('%s_acc._vs._loss.png' % self.name)
-        print('Successfully saved the figure at current location')
\ No newline at end of file
+        print('Successfully saved the figure at current location')
+
+def test_train_split(data, parameters, xh, test_size):
+    """
+        : data: enter the data
+        : parameters: enter the parameters
+        : test_size: enter the size of your test set
+        :return: split the data in test and train sets
+    """
+    ind = np.random.randint(low=0, high=len(data), size=test_size)
+    params_test = parameters[ind]
+    data_test = data[ind]
+    xh_test = xh[ind]
+
+    params_train = np.delete(parameters, ind, axis=0)
+    data_train = np.delete(data, ind, axis=0)
+    xh_train = np.delete(xh, ind, axis=0)
+
+    return params_test, params_train, data_test, data_train, xh_test, xh_train
\ No newline at end of file
