@@ -11,21 +11,20 @@ class Predict:
         Epoch of Reionization(EoR) 21-cm powerspectrum and Bispectrum,
         provided astrophysical parameters (Mhmin,Nion,Rmfp)
     """
-    def __init__(self, params):
-        self.model = ks.models.load_model
-        self.params = params
+    def __init__(self,):
+        pass
 
-    def existing_models(self, stats):
+    def existing_models(self, params, stats,):
         """
         stats: int(0, 1)
         choose 0 for powerspectrum, and 1 for bispectrum
         """
         load_model = path+'%s' % ex_models[stats]
-        model = self.model(load_model)
-        model = model.predict(self.params)
+        model = ks.models.load_model(load_model)
+        model = model.predict(params)
         return model
 
-    def model(self, load_model):
+    def model(self, load_model, params):
         """
         The 21-cm powerspectrum or 21-cm Bispectrum from k1 range (0.2-1.5) mpc^-1
         based on Artificial Neural Networks(ANN),
@@ -34,6 +33,6 @@ class Predict:
             :returns: emulated P(k) or B(k1,k2,k3)
         """
 
-        model = self.model(load_model)
-        model = model.predict(self.params)
-        return model
\ No newline at end of file
+        model = ks.models.load_model(load_model)
+        pred = model.predict(params)
+        return pred
\ No newline at end of file
