@@ -40,36 +40,38 @@ class AnimatePk:
         self.pk_pred = pk_pred * norm
 
     def get_animation_pk(self):
-        fig = plt.figure(figsize=(10, 7))
-        plt.style.use('seaborn')
-        plt.grid(color='white', lw=1.5)
+        fig = plt.figure(figsize=(8, 6), facecolor='w', )
+        plt.style.use('classic')
+        plt.suptitle(r'$\rm Simulation$' r' $vs.$' r'$\rm ANN$ ' r'$\rm Prediction$',
+                     size=20, )
+        plt.xlabel(r'$\rm{k(Mpc^{-1})}$', size=20, )
+        plt.ylabel(r'$\rm \Delta^2[mK^2]$', size=20, )
+        plt.xscale('log')
+        plt.xlim(0.1, 3.2)
+        plt.grid()
+        plt.ylim(0, int(np.max(self.test_data) + 20))
         camera = Camera(fig)
-        for i in range(15):
-            plt.suptitle('EoR 21-cm Powerspectrum, Simulation vs. ANN Prediction',
-                         size=20, color='Darkblue')
-            plt.xlabel(r'$\mathrm{k(Mpc^{-1})}$', size=20, color='darkblue')
-            plt.ylabel(r'$\rm k^3P(k)/2\pi^2(mK^2)$', size=25, color='Darkblue')
-            plt.xscale('log')
-            plt.ylim(0, int(np.max(self.test_data)+80))
-            plt.yscale('symlog')
-            plt.plot(self.k, self.pk_pred[i], marker='o', ls='-', color='blue', lw=3)
-            plt.plot(self.k, self.test_data[i], ls='--', lw=2, color='red')
-            plt.legend(['ANN Prediction',
-                        r' Powerspectrum for $\rm \zeta = {0:.2f}, '
-                        r'Rmfp = {1:.2f}, Mhmin(10^8 M\odot) = {2:.1f}$'
+        for i in range(len(self.test_data)):
+            plt.plot(self.k, self.pk_pred[i], ls='-', color='k', lw=2)
+            plt.plot(self.k, self.test_data[i], 'o', color='b')
+            plt.legend([r'$\rm ANN $' r' $\rm Prediction $',
+                        r'$\rm P(k); N_{{ion}} = {0:.2f}, '
+                        r'R_{{mfp}}(Mpc) = {1:.2f}, Mhalo_{{min}}(10^9 M_\odot) = {2:.1f}$'
                        .format(self.test_params[i, 1], self.test_params[i, 2],
-                               self.test_params[i, 0], self.xh_test[i])],
-                       loc='lower right', prop={'size': 13})
+                               self.test_params[i, 0]/10., self.xh_test[i])],
+                       loc='upper right', prop={'size': 13})
+
             camera.snap()
         animation = camera.animate()
         animation.save('pk.gif', fps=1, dpi=160)
+
         print('pk.gif saved!')
+        plt.close()
 
 
 class AnimateBk:
 
     def __init__(self, bk_test, params_test, ntri, xh, load_model=path+ex_models[1],
-                 cos_min=0.50, cos_max=0.99, cos_step=0.1,
                  k2byk1_min=0.50, k2byk1_max=1.00, k2byk1_step=0.05, norm=100.):
         """
         simulation specific function, will not be so useful on more than 3 EoR parameters.
@@ -95,7 +97,7 @@ class AnimateBk:
         self.params_test = params_test
         self.xh = xh
         k2byk1 = np.arange(k2byk1_min, k2byk1_max + k2byk1_step, k2byk1_step)
-        costheta = np.arange(cos_min, cos_max + cos_step, cos_step)
+        #  costheta = np.arange(cos_min, cos_max + cos_step, cos_step)
         self.costheta = costheta
         self.k2byk1 = np.reshape(k2byk1, (len(k2byk1), 1))
         # cond = costheta.reshape(len(costheta), 1) * k2byk1.reshape(1, len(k2byk1))
@@ -111,17 +113,9 @@ class AnimateBk:
         bk_pred_dummy = model.predict(self.params_test)
         bk_pred_dummy = bk_pred_dummy * norm
         bk_pred_dummy = np.reshape(bk_pred_dummy, np.shape(bk_test_dummy))
-        bk_test = np.zeros(shape=(len(self.params_test), len(k2byk1) * len(costheta)))
+        bk_test = np.zeros(shape=(len(self.params_test), len(self.k1), len(k2byk1) * len(costheta)))
         bk_pdct = np.zeros(shape=bk_test.shape)
-        ntri = np.zeros(shape=len(k2byk1) * len(costheta))
-        ntri[non_na_index] = ntri_dummy
-        for i in range(len(self.xh)):
-            bk_pdct[i][non_na_index] = bk_pred_dummy[i]
-            bk_test[i][non_na_index] = bk_test_dummy[i]
-        bk_test = np.zeros(shape=(len(self.params_test),
-                                  len(self.k1), len(k2byk1) * len(costheta)))
-        bk_pdct = np.zeros(shape=bk_test.shape)
-        ntri = np.zeros(shape=(len(self.k1), len(costheta)*len(k2byk1)))
+        ntri = np.zeros(shape=(len(self.k1), len(costheta) * len(k2byk1)))
         for i in range(len(self.k1)):
             ntri[i][non_na_index] = ntri_dummy[i]
 
@@ -151,7 +145,7 @@ class AnimateBk:
         :returns: Animation between simulated Bispectrum and ANN predictions.
         """
         for i in range(len(self.xh)):
-            fig, axes = plt.subplots(nrows=2, ncols=5, figsize=(26, 8), sharex='True', sharey='True')
+            fig, axes = plt.subplots(nrows=2, ncols=5, figsize=(26, 8), sharex=True, sharey=True)
             b = np.array([self.bk_test[i][0], self.bk_test[i][1], self.bk_test[i][2],
                           self.bk_test[i][3], self.bk_test[i][4],
                           self.bk_pdct[i][0], self.bk_pdct[i][1], self.bk_pdct[i][2],
@@ -174,16 +168,6 @@ class AnimateBk:
                          r'$\mathrm{k_1(Mpc^{-1})}$ = 0.92           '
                          r'$\mathrm{k_1(Mpc^{-1})}$ = 1.55',
                          size=20)
-                fig.text(0.435, 0.04, r'$\mathrm{cos(\theta)}$', ha='center', size=30)
-                fig.text(0.05, 0.5, r'$\mathrm{k_2/k_1}$', va='center', rotation='vertical', size=30)
-                fig.text(0.09, 0.71, r'Simulation', va='center', rotation='vertical', size=25)
-                fig.text(0.09, 0.31, r'Emulation', va='center', rotation='vertical', size=25)
-                fmt = ticker.ScalarFormatter(useMathText=True)
-                fmt.set_powerlimits((0, 0))
-                cbar = fig.colorbar(im, label=r"$(k_1^3.k_2^3.B(k_1,k_2,k_3)/(2\pi^2)^2)[mK^3]$",
-                                    ax=axes.ravel().tolist(), format=fmt)
-                cbar.ax.yaxis.label.set_size(25.)
-                plt.savefig('Bk_%d.jpg' % i, dpi=120, bbox_inches='tight')
             fmt = ticker.ScalarFormatter(useMathText=True)
             fmt.set_powerlimits((0, 0))
             cbar = fig.colorbar(im, label=r"$\rm (k_1^3.k_2^3.B(k_1,k_2,k_3)/(2\pi^2)^2)[mK^3]$",
@@ -200,7 +184,35 @@ class AnimateBk:
                 images.append(imageio.imread(file_path))
         imageio.mimsave('Bk.gif', images, fps=1)
         os.system('rm Bk_*.jpg')
-    print('Bk.gif saved!')
+        print('Bk.gif saved!')
+
+        fig, axes = plt.subplots(nrows=2, ncols=5, figsize=(14, 6), sharex=True, sharey=True, facecolor='w')
+        plt.style.use('classic')
+        # Bk = [bk[i][0], bk[i][1], bk[i][2], bk[i][3], bk[i][4],bkpd[i][0], bkpd[i][1], bkpd[i][2], bkpd[i][3], bkpd[i][4]]
+        for j, ax in zip(Bk[i], axes.flat):
+            bounds = np.array([-3e3, -1e3, -1e2, -1e1, 0, 1e0, 1e1, 1e2, 1e3, 3e3, 4e4, 8e4, 1e5, ])
+            norm = colors.BoundaryNorm(boundaries=bounds, ncolors=265)
+            im = ax.imshow(j, origin='lower', cmap='RdBu', extent=[0.50, 0.99, 0.52, .97],
+                           norm=norm)  # ,corner_mask=False)
+        fig.text(0.51, 0.565, r'$\rm \mathrm{cos(\theta)}$', ha='center', size=20)
+        fig.text(0.135, 0.91, r'$\rm k_1(Mpc^{-1})=0.19$'
+                              '                    $0.32$'
+                              '                            $0.54$'
+                              '                            $0.92$'
+                              '                             $1.55$', size=15)
+        fig.text(0.08, 0.6, r'$\mathrm{k_2/k_1}$', va='center', rotation='vertical', size=20)
+        fig.text(0.065, 0.76, r'$\rm Simulation$', va='center', rotation='vertical', size=20)
+        fig.text(0.065, 0.41, r'$\rmEmulation$', va='center', rotation='vertical', size=20)
+        # plt.hlines(y=0.5,xmin=0.1,xmax=0.5)
+        cbar = fig.colorbar(im, label=r"$\rm k_1^3.k_2^3.B(k_1,k_2,k_3)/(2\pi^2)^2[mK^3]; N_{{ion}}={0:.2f},"
+                                      "R_{{mfp}}={1:.2f}, Mhalo_{{min}}={2:.1f}$".format(params[i, 1], params[i, 2],
+                                                                                         params[i, 0])
+                            , ax=axes.ravel().tolist(), orientation='horizontal',
+                            fraction=0.15, aspect=70, pad=0.05,
+                            format=ticker.FuncFormatter(fmt))
+        cbar.ax.xaxis.label.set_size(18)
+        # plt.colorbar( )
+        plt.savefig('Bk_norm%d.pdf' % i, dpi=120, bbox_inches='tight')
 
     def get_bk_vs_cos(self,):
         """
@@ -242,32 +254,27 @@ class AnimateBk:
 class GetPosterior:
     """
     Returns the posterior distribution
-    :params : the posterior parameter array
+    :data: the posterior parameter array
     walks in the paramter space: type array( N * (no. of parameters) )
-    :logl: array contains the values of
-    loglikelihood : type array(N*1)
-    :name: Powerpsectrum, Bispectrum
+    :truth: true values of parameters, if avaiable
     """
 
-    def __init__(self, data):
+    def __init__(self, data, truth):
         self.c = ChainConsumer()
-        parameters = [r"$\zeta$", "$R_{mfp}$", r"$Mh_{min} \times 10^8 M\odot$"]
+        parameters = [r"$\zeta$", r"$R_{mfp}$", r"$Mh_{min} \times 10^8 M\odot$"]
         self.parameters = parameters
-        self.data = np.array([data[:, 1], data[:, 2], data[:, 0]])
-
+        self.data = np.reshape(np.array([data[:, 1], data[:, 2], data[:, 0]]), (len(data[:, 1]), len(parameters)))
+        self.truth = [truth[1], truth[2], truth[0]]
+        
     def corner(self, index, name='bk', color='blue', dpi=120):
         """
         :param index: index for the plot, type int
-        :param name: statistics used, e.g. Powerspectrum, Bispectrum
+        :param name: statistics used, e.g. use 'pk' for Powerspectrum, 'bk' for Bispectrum
         :param color: color
         :param dpi: dpi of the plot
         """
         self.c.add_chain(self.data, parameters=self.parameters, color=color)
-        self.c.add_chain(self.data, parameters=['zeta', 'rmfp', 'noh'], color=color)
-
-        fig = self.c.plotter.plot(figsize=1.0)
-
+        fig = self.c.plotter.plot(figsize=1.0, truth=self.truth)
         fig.set_size_inches(3 + fig.get_size_inches())
-
         fig.savefig('{0:s}_{1:d}.jpg'.format(name, index), dpi=dpi)
-        print('{0:s}_{1:d}.jpg saved'.format(name, index))
\ No newline at end of file
+        print('{0:s}_{1:d}.jpg saved'.format(name, index))
